@@ -27,6 +27,17 @@ impl TwMap {
             Some(l) => T::get(l),
         }
     }
+
+    /// Returns a mutable reference to the specified physics layer, if the map contains it.
+    /// Note that every map must have a Game layer to pass the checks.
+    pub fn find_physics_layer_mut<T: PhysicsLayerChecking>(&mut self) -> Option<&mut T> {
+        match self.physics_group_mut().layers.iter_mut()
+            .rev()
+            .find(|l| l.kind() == T::kind()) {
+            None => None,
+            Some(l) => T::get_mut(l),
+        }
+    }
 }
 
 impl LayerKind {
@@ -839,12 +850,8 @@ impl Group {
         let lowest_up_shrink = i32::try_from(lowest_up_shrink).ok()?;
         let lowest_left_shrink = i32::try_from(lowest_left_shrink).ok()?;
         // shrinking the layers from up and left moves them, so the offset has to correct that
-        self.offset_y = self.offset_y.checked_sub(lowest_up_shrink.checked_mul(32)?)?
-            .checked_mul(self.parallax_y)?
-            .checked_div(100)?;
-        self.offset_x = self.offset_x.checked_sub(lowest_left_shrink.checked_mul(32)?)?
-            .checked_mul(self.parallax_x)?
-            .checked_div(100)?;
+        self.offset_y = self.offset_y.checked_sub(lowest_up_shrink.checked_mul(32)?)?;
+        self.offset_x = self.offset_x.checked_sub(lowest_left_shrink.checked_mul(32)?)?;
         Some(self)
     }
 
@@ -913,12 +920,8 @@ impl Group {
         let lowest_up_shrink = i32::try_from(lowest_up_shrink).ok()?;
         let lowest_left_shrink = i32::try_from(lowest_left_shrink).ok()?;
         // shrinking the layers from up and left moves them, so the offset has to correct that
-        self.offset_y = self.offset_y.checked_sub(lowest_up_shrink.checked_mul(32)?)?
-            .checked_mul(self.parallax_y)?
-            .checked_div(100)?;
-        self.offset_x = self.offset_x.checked_sub(lowest_left_shrink.checked_mul(32)?)?
-            .checked_mul(self.parallax_x)?
-            .checked_div(100)?;
+        self.offset_y = self.offset_y.checked_sub(lowest_up_shrink.checked_mul(32)?)?;
+        self.offset_x = self.offset_x.checked_sub(lowest_left_shrink.checked_mul(32)?)?;
         Some(self)
     }
 }
